from typing import Any, List

from fastapi import UploadFile, File
from fastapi import APIRouter, Depends, HTTPException
from fastapi.responses import FileResponse
from sqlalchemy.orm import Session

import app.crud as crud
import app.models as models
import app.schemas as schemas 
from app.api import deps

router = APIRouter()

@router.get("/", response_model=List[schemas.Video])
def get_video_list(
    db: Session = Depends(deps.get_db),
    skip: int = 0,
    limit: int = 100,
    current_user: models.User = Depends(deps.get_current_active_user),
) -> Any:
    """
    Retrieve items.
    """
    if crud.user.is_superuser(current_user):
        items = crud.item.get_multi(db, skip=skip, limit=limit)
    else:
        items = crud.item.get_multi_by_owner(
            db=db, owner_id=current_user.id, skip=skip, limit=limit
        )
    return items

@router.post("/", response_model=schemas.Item)
def upload_plot(
    *,
    db: Session = Depends(deps.get_db),
    title: str,
    zip_file: UploadFile=File(),
    current_user: models.User = Depends(deps.get_current_active_user),
) -> Any:
    """
    Create new video.
    """
    video_create = schemas.VideoCreate
    video_create.title = title
    file_name = crud.video.generate_file_name(db=db, n=20)
    video_create.stored_file_name = file_name
    video = crud.video.create_with_owner(db=db, obj_in=video_create, owner_id=current_user.id)
    return video

@router.get("/{id}", response_model=FileResponse)
def download_video(
    *,
    db: Session = Depends(deps.get_db),
    id: int,
    current_user: models.User = Depends(deps.get_current_active_user),
) -> Any:
    video = crud.video.get(db=db, id=id)
    if video:
      pass
        #return FileResponse(path=str(USER_FILE.joinpath(str(id), "output.mp4")), filename=video['filename']+".mp4")
    else:
        pass
@router.get("/worker/{id}")
def download_plot(

) -> Any:
    pass

@router.get("/worker")
def upload_complete_video(

) -> Any:
    pass